# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_playwright_script_properties import AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties
from typing import Optional, Set
from typing_extensions import Self

class AgentsGraphModelsNodesPropertiesIrisProperties(BaseModel):
    """
    AgentsGraphModelsNodesPropertiesIrisProperties
    """ # noqa: E501
    type: StrictStr
    instructions: StrictStr
    tools: List[StrictStr]
    snapshot_compression: StrictBool
    temperature: Union[StrictFloat, StrictInt]
    batch_actions: StrictBool
    playwright_script_properties: Optional[AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties] = None
    learn_and_compile: Optional[StrictBool] = None
    model: StrictStr
    __properties: ClassVar[List[str]] = ["type", "instructions", "tools", "snapshot_compression", "temperature", "batch_actions", "playwright_script_properties", "learn_and_compile", "model"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['iris']):
            raise ValueError("must be one of enum values ('iris')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsNodesPropertiesIrisProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of playwright_script_properties
        if self.playwright_script_properties:
            _dict['playwright_script_properties'] = self.playwright_script_properties.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsNodesPropertiesIrisProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "instructions": obj.get("instructions"),
            "tools": obj.get("tools"),
            "snapshot_compression": obj.get("snapshot_compression"),
            "temperature": obj.get("temperature"),
            "batch_actions": obj.get("batch_actions"),
            "playwright_script_properties": AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties.from_dict(obj["playwright_script_properties"]) if obj.get("playwright_script_properties") is not None else None,
            "learn_and_compile": obj.get("learn_and_compile"),
            "model": obj.get("model")
        })
        return _obj





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from asteroid_odyssey.models.agent_list200_response import AgentList200Response
from asteroid_odyssey.models.agents_agent_execute_agent_request import AgentsAgentExecuteAgentRequest
from asteroid_odyssey.models.agents_agent_execute_agent_response import AgentsAgentExecuteAgentResponse
from asteroid_odyssey.models.agents_agent_sort_field import AgentsAgentSortField
from asteroid_odyssey.models.common_sort_direction import CommonSortDirection

from asteroid_odyssey.api_client import ApiClient, RequestSerialized
from asteroid_odyssey.api_response import ApiResponse
from asteroid_odyssey.rest import RESTResponseType


class AgentsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def agent_execute_post(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to execute")],
        agents_agent_execute_agent_request: Annotated[AgentsAgentExecuteAgentRequest, Field(description="Execution request parameters")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentsAgentExecuteAgentResponse:
        """Execute an agent

        Start an execution for the given agent.

        :param agent_id: The ID of the agent to execute (required)
        :type agent_id: str
        :param agents_agent_execute_agent_request: Execution request parameters (required)
        :type agents_agent_execute_agent_request: AgentsAgentExecuteAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_execute_post_serialize(
            agent_id=agent_id,
            agents_agent_execute_agent_request=agents_agent_execute_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AgentsAgentExecuteAgentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_execute_post_with_http_info(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to execute")],
        agents_agent_execute_agent_request: Annotated[AgentsAgentExecuteAgentRequest, Field(description="Execution request parameters")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentsAgentExecuteAgentResponse]:
        """Execute an agent

        Start an execution for the given agent.

        :param agent_id: The ID of the agent to execute (required)
        :type agent_id: str
        :param agents_agent_execute_agent_request: Execution request parameters (required)
        :type agents_agent_execute_agent_request: AgentsAgentExecuteAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_execute_post_serialize(
            agent_id=agent_id,
            agents_agent_execute_agent_request=agents_agent_execute_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AgentsAgentExecuteAgentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_execute_post_without_preload_content(
        self,
        agent_id: Annotated[StrictStr, Field(description="The ID of the agent to execute")],
        agents_agent_execute_agent_request: Annotated[AgentsAgentExecuteAgentRequest, Field(description="Execution request parameters")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Execute an agent

        Start an execution for the given agent.

        :param agent_id: The ID of the agent to execute (required)
        :type agent_id: str
        :param agents_agent_execute_agent_request: Execution request parameters (required)
        :type agents_agent_execute_agent_request: AgentsAgentExecuteAgentRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_execute_post_serialize(
            agent_id=agent_id,
            agents_agent_execute_agent_request=agents_agent_execute_agent_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AgentsAgentExecuteAgentResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_execute_post_serialize(
        self,
        agent_id,
        agents_agent_execute_agent_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params['agentId'] = agent_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agents_agent_execute_agent_request is not None:
            _body_params = agents_agent_execute_agent_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/agents/{agentId}/execute',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_list(
        self,
        organization_id: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Optional[StrictStr] = None,
        sort_field: Optional[AgentsAgentSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentList200Response:
        """List Agents

        List all agents for an organization

        :param organization_id:
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name:
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsAgentSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentList200Response",
            '400': "str",
            '404': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_list_with_http_info(
        self,
        organization_id: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Optional[StrictStr] = None,
        sort_field: Optional[AgentsAgentSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentList200Response]:
        """List Agents

        List all agents for an organization

        :param organization_id:
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name:
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsAgentSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentList200Response",
            '400': "str",
            '404': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_list_without_preload_content(
        self,
        organization_id: Optional[StrictStr] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Optional[StrictStr] = None,
        sort_field: Optional[AgentsAgentSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Agents

        List all agents for an organization

        :param organization_id:
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name:
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsAgentSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentList200Response",
            '400': "str",
            '404': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_list_serialize(
        self,
        organization_id,
        page_size,
        page,
        search_name,
        sort_field,
        sort_direction,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if organization_id is not None:
            
            _query_params.append(('organizationId', organization_id))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if search_name is not None:
            
            _query_params.append(('searchName', search_name))
            
        if sort_field is not None:
            
            _query_params.append(('sortField', sort_field.value))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'text/plain'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agents',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from asteroid_odyssey.models.agents_graph_models_type_input_method import AgentsGraphModelsTypeInputMethod
from typing import Optional, Set
from typing_extensions import Self

class AgentsGraphModelsSettings(BaseModel):
    """
    Configuration settings for workflow execution
    """ # noqa: E501
    max_iterations: StrictInt = Field(description="Maximum number of iterations")
    viewport_width: StrictInt = Field(description="Browser viewport width in pixels")
    viewport_height: StrictInt = Field(description="Browser viewport height in pixels")
    trim_screenshots: StrictBool = Field(description="Whether to trim screenshots")
    max_timeout_mins: StrictInt = Field(description="Maximum timeout in minutes")
    type_input_method: AgentsGraphModelsTypeInputMethod = Field(description="Text input method for browser automation")
    summarise: Optional[StrictBool] = Field(default=None, description="Whether to summarize execution results")
    new_agent_loop: Optional[StrictBool] = Field(default=None, description="Whether to use the new agent loop for execution (admin-only setting)")
    __properties: ClassVar[List[str]] = ["max_iterations", "viewport_width", "viewport_height", "trim_screenshots", "max_timeout_mins", "type_input_method", "summarise", "new_agent_loop"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "max_iterations": obj.get("max_iterations"),
            "viewport_width": obj.get("viewport_width"),
            "viewport_height": obj.get("viewport_height"),
            "trim_screenshots": obj.get("trim_screenshots"),
            "max_timeout_mins": obj.get("max_timeout_mins"),
            "type_input_method": obj.get("type_input_method"),
            "summarise": obj.get("summarise"),
            "new_agent_loop": obj.get("new_agent_loop")
        })
        return _obj





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from asteroid_odyssey.models.agents_graph_models_agent_graph import AgentsGraphModelsAgentGraph
from asteroid_odyssey.models.agents_graph_models_settings import AgentsGraphModelsSettings
from asteroid_odyssey.models.agents_workflow_environment_template import AgentsWorkflowEnvironmentTemplate
from typing import Optional, Set
from typing_extensions import Self

class AgentsWorkflowWorkflowSnapshot(BaseModel):
    """
    A workflow (commit) representing an immutable snapshot of agent configuration
    """ # noqa: E501
    id: StrictStr = Field(description="The unique ID of this workflow")
    agent_id: StrictStr = Field(description="The agent ID this workflow belongs to", alias="agentId")
    parent_id: Optional[StrictStr] = Field(default=None, description="The ID of the parent workflow this was derived from (for lineage tracking)", alias="parentId")
    version: Optional[StrictInt] = Field(default=None, description="The published version number. Null if unpublished.")
    rules: StrictStr = Field(description="The rules/instructions for this workflow")
    settings: AgentsGraphModelsSettings = Field(description="The settings for this workflow")
    task: Optional[StrictStr] = Field(default=None, description="The task description")
    inputs: List[StrictStr] = Field(description="Input placeholders for workflow execution")
    graph: AgentsGraphModelsAgentGraph = Field(description="The workflow graph")
    created_at: datetime = Field(description="When this workflow was created", alias="createdAt")
    author: Optional[StrictStr] = Field(default=None, description="The email of the user who created this workflow.")
    environment_template: Optional[AgentsWorkflowEnvironmentTemplate] = Field(default=None, description="Optional environment template. Defaults to browser/anchor if not provided.", alias="environmentTemplate")
    __properties: ClassVar[List[str]] = ["id", "agentId", "parentId", "version", "rules", "settings", "task", "inputs", "graph", "createdAt", "author", "environmentTemplate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsWorkflowWorkflowSnapshot from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of graph
        if self.graph:
            _dict['graph'] = self.graph.to_dict()
        # override the default output from pydantic by calling `to_dict()` of environment_template
        if self.environment_template:
            _dict['environmentTemplate'] = self.environment_template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsWorkflowWorkflowSnapshot from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "agentId": obj.get("agentId"),
            "parentId": obj.get("parentId"),
            "version": obj.get("version"),
            "rules": obj.get("rules"),
            "settings": AgentsGraphModelsSettings.from_dict(obj["settings"]) if obj.get("settings") is not None else None,
            "task": obj.get("task"),
            "inputs": obj.get("inputs"),
            "graph": AgentsGraphModelsAgentGraph.from_dict(obj["graph"]) if obj.get("graph") is not None else None,
            "createdAt": obj.get("createdAt"),
            "author": obj.get("author"),
            "environmentTemplate": AgentsWorkflowEnvironmentTemplate.from_dict(obj["environmentTemplate"]) if obj.get("environmentTemplate") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class AgentsFilesFile(BaseModel):
    """
    AgentsFilesFile
    """ # noqa: E501
    id: StrictStr
    execution_id: StrictStr = Field(alias="executionId")
    agent_id: StrictStr = Field(alias="agentId")
    file_path: StrictStr = Field(alias="filePath")
    file_name: StrictStr = Field(alias="fileName")
    file_ext: StrictStr = Field(alias="fileExt")
    file_size: StrictInt = Field(alias="fileSize")
    file_type: StrictStr = Field(alias="fileType")
    mime_type: StrictStr = Field(alias="mimeType")
    created_at: datetime = Field(alias="createdAt")
    signed_url: StrictStr = Field(alias="signedUrl")
    __properties: ClassVar[List[str]] = ["id", "executionId", "agentId", "filePath", "fileName", "fileExt", "fileSize", "fileType", "mimeType", "createdAt", "signedUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsFilesFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsFilesFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "executionId": obj.get("executionId"),
            "agentId": obj.get("agentId"),
            "filePath": obj.get("filePath"),
            "fileName": obj.get("fileName"),
            "fileExt": obj.get("fileExt"),
            "fileSize": obj.get("fileSize"),
            "fileType": obj.get("fileType"),
            "mimeType": obj.get("mimeType"),
            "createdAt": obj.get("createdAt"),
            "signedUrl": obj.get("signedUrl")
        })
        return _obj


